@@ -1,6 +1,6 @@
 /* varobj support for Ada.
 
-   Copyright (C) 2012-2025 Free Software Foundation, Inc.
+   Copyright (C) 2012-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -100,7 +100,7 @@ ada_varobj_struct_elt (struct value *parent_value,
 
   if (parent_value)
     {
-      value = value_field (parent_value, fieldno);
+      value = parent_value->field (fieldno);
       type = value->type ();
     }
   else
