@@ -1,6 +1,6 @@
 /* Very simple "bfd" target, for GDB, the GNU debugger.
 
-   Copyright (C) 2003-2024 Free Software Foundation, Inc.
+   Copyright (C) 2003-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef BFD_TARGET_H
-#define BFD_TARGET_H
+#ifndef GDB_BFD_TARGET_H
+#define GDB_BFD_TARGET_H
 
 #include "gdb_bfd.h"
 
@@ -27,4 +27,4 @@ struct target_ops;
 /* Given an existing BFD, re-open it as a "struct target_ops".  */
 target_ops_up target_bfd_reopen (const gdb_bfd_ref_ptr &bfd);
 
-#endif
+#endif /* GDB_BFD_TARGET_H */
