@@ -1,6 +1,6 @@
 /* Routines for handling XML generic OS data provided by target.
 
-   Copyright (C) 2008-2024 Free Software Foundation, Inc.
+   Copyright (C) 2008-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -21,7 +21,7 @@
 #include "xml-support.h"
 #include "osdata.h"
 #include "ui-out.h"
-#include "gdbcmd.h"
+#include "cli/cli-cmds.h"
 
 #if !defined(HAVE_LIBEXPAT)
 
@@ -63,7 +63,7 @@ osdata_start_osdata (struct gdb_xml_parser *parser,
     gdb_xml_error (parser, _("Seen more than on osdata element"));
 
   char *type = (char *) xml_find_attribute (attributes, "type")->value.get ();
-  data->osdata.reset (new struct osdata (std::string (type)));
+  data->osdata = std::make_unique<osdata> (std::string (type));
 }
 
 /* Handle the start of a <item> element.  */
@@ -209,7 +209,7 @@ info_osdata (const char *type)
 
   if (*type == '\0' && nrows == 0)
     error (_("Available types of OS data not reported."));
-  
+
   if (!osdata->items.empty ())
     {
       last = &osdata->items.back ();
@@ -287,9 +287,7 @@ info_osdata_command (const char *arg, int from_tty)
   info_osdata (arg);
 }
 
-void _initialize_osdata ();
-void
-_initialize_osdata ()
+INIT_GDB_FILE (osdata)
 {
   add_info ("os", info_osdata_command,
 	   _("Show OS data ARG."));
