@@ -1,6 +1,6 @@
 /* Language independent support for printing types for GDB, the GNU debugger.
 
-   Copyright (C) 1986-2025 Free Software Foundation, Inc.
+   Copyright (C) 1986-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -515,6 +515,18 @@ ptype_command (const char *type_name, int from_tty)
   whatis_exp (type_name, 1);
 }
 
+/* Meant to be used in debug sessions, so don't export it in a header file.  */
+extern void ATTRIBUTE_UNUSED debug_type (struct type *type);
+
+/* Print TYPE.  */
+
+void ATTRIBUTE_UNUSED
+debug_type (struct type *type)
+{
+  type_print (type, "", gdb_stdlog, 1);
+  gdb_flush (gdb_stdlog);
+}
+
 /* Print integral scalar data VAL, of type TYPE, onto stdio stream STREAM.
    Used to print data from type structures in a specified type.  For example,
    array bounds may be characters or booleans in some languages, and this
